# Python Substack

# Introduction

This is an unofficial library providing a Python interface for [Substack](https://substack.com/).
I am in no way affiliated with Substack. It works with
Python versions from 3.8+.

# Installation

You can install python-substack using:

    $ pip install python-substack